import { Direction, Orientation } from "@microsoft/fast-web-utilities";
import { FormAssociated } from "../form-associated/index";
export declare enum SliderMode {
    singleValue = "single-value"
}
export interface SliderConfiguration {
    max: number;
    min: number;
    orientation?: Orientation;
    direction?: Direction;
    disabled?: boolean;
}
export declare class Slider extends FormAssociated<HTMLInputElement> implements SliderConfiguration {
    readOnly: boolean;
    private readOnlyChanged;
    track: HTMLDivElement;
    thumb: HTMLDivElement;
    direction: Direction;
    isDragging: boolean;
    position: string;
    trackWidth: number;
    trackMinWidth: number;
    trackHeight: number;
    trackMinHeight: number;
    /**
     * The element's value to be included in form submission changed.
     */
    value: string;
    private valueChanged;
    /**
     * Min allowed value default is 0
     */
    min: number;
    private minChanged;
    /**
     * Max allowed value default is 10
     */
    max: number;
    private maxChanged;
    /**
     * Value to increment or decrement via arrow keys, mouse click or drag
     */
    step: number;
    private stepChanged;
    /**
     * Orientation value, horizontal | vertical
     */
    orientation: Orientation;
    private orientationChanged;
    /**
     * mode value, default singleValue
     */
    mode: SliderMode;
    protected proxy: HTMLInputElement;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    increment: () => void;
    decrement: () => void;
    protected keypressHandler: (e: KeyboardEvent) => void;
    private setThumbPositionForOrientation;
    private getDirection;
    private setupTrackConstraints;
    private setupListeners;
    private setupDefaultValue;
    private updateForm;
    /**
     *  Handle mouse moves during a thumb drag operation
     */
    private handleThumbMouseDown;
    /**
     *  Handle mouse moves during a thumb drag operation
     */
    private handleMouseMove;
    private calculateNewValue;
    /**
     * Handle a window mouse up during a drag operation
     */
    private handleWindowMouseUp;
    private stopDragging;
    private clickHandler;
    private convertToConstrainedValue;
}
